@@ -629,7 +629,8 @@ class Mobject(object):
             sm1.depth_test = sm2.depth_test
             sm1.render_primitive = sm2.render_primitive
         self.refresh_bounding_box(recurse_down=True)
-        self.match_updaters(mobject)
+        # self.match_updaters(mobject)
+        # This line makes the Mobject method always_redraw not work
         return self
 
     def looks_identical(self, mobject: Mobject):
